@@ -986,7 +986,7 @@ class AuthenticationClient(object):
             'UI',
             'BUTTON'
         ]
-        if not valid_resource_types.index(resource_type):
+        if resource_type and resource_type not in valid_resource_types:
             raise AuthingWrongArgumentException('invalid argument: resource_type')
         data = self.graphqlClient.request(
             query=QUERY['listUserAuthorizedResources'],
@@ -994,7 +994,8 @@ class AuthenticationClient(object):
                 'id': user.get('id'),
                 'namespace': namespace,
                 'resourceType': resource_type
-            }
+            },
+            token=self._get_token(),
         )
         data = data.get('user')
         if not data:
