@@ -11,6 +11,7 @@ from .roles import RolesManagementClient
 from .acl import AclManagementClient
 from .udf import UdfManagementClient
 from .groups import GroupsManagementClient
+from .orgs import OrgManagementClient
 from ..common.rest import RestClient
 
 
@@ -74,6 +75,12 @@ class ManagementClient(object):
             tokenProvider=self.tokenProvider
         )
 
+        self.org = OrgManagementClient(
+            options=self.options,
+            graphqlClient=self.graphqlClient,
+            tokenProvider=self.tokenProvider
+        )
+
         # 用户池详情
         self._userpool_detail = None
 
