@@ -239,7 +239,7 @@ class RolesManagementClient(object):
                 'UI',
                 'BUTTON'
             ]
-            if not valid_resource_types.index(resource_type):
+            if resource_type and resource_type not in valid_resource_types:
                 raise AuthingWrongArgumentException('invalid argument: resource_type')
 
         data = self.graphqlClient.request(
